==> apache-iceberg-1.9.0.tar.gz: apache-iceberg-1.9.0/core/src/test/java/org/apache/iceberg/encryption/EncryptionTestHelpers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.encryption;

import java.util.Map;
import org.apache.iceberg.CatalogProperties;
import org.apache.iceberg.TableProperties;
import org.apache.iceberg.relocated.com.google.common.collect.Maps;

public class EncryptionTestHelpers {

  private EncryptionTestHelpers() {}

  public static EncryptionManager createEncryptionManager() {
    Map<String, String> catalogProperties = Maps.newHashMap();
    catalogProperties.put(
        CatalogProperties.ENCRYPTION_KMS_IMPL, UnitestKMS.class.getCanonicalName());
    Map<String, String> tableProperties = Maps.newHashMap();
    tableProperties.put(TableProperties.ENCRYPTION_TABLE_KEY, UnitestKMS.MASTER_KEY_NAME1);
    tableProperties.put(TableProperties.FORMAT_VERSION, "2");

    return EncryptionUtil.createEncryptionManager(
        tableProperties, EncryptionUtil.createKmsClient(catalogProperties));
  }
}

==> apache-iceberg-1.10.0.tar.gz: apache-iceberg-1.10.0/core/src/test/java/org/apache/iceberg/encryption/EncryptionTestHelpers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.encryption;

import java.util.List;
import java.util.Map;
import org.apache.iceberg.CatalogProperties;
import org.apache.iceberg.TableProperties;
import org.apache.iceberg.relocated.com.google.common.collect.Maps;

public class EncryptionTestHelpers {

  private EncryptionTestHelpers() {}

  public static EncryptionManager createEncryptionManager() {
    Map<String, String> catalogProperties = Maps.newHashMap();
    catalogProperties.put(
        CatalogProperties.ENCRYPTION_KMS_IMPL, UnitestKMS.class.getCanonicalName());
    Map<String, String> tableProperties = Maps.newHashMap();
    tableProperties.put(TableProperties.ENCRYPTION_TABLE_KEY, UnitestKMS.MASTER_KEY_NAME1);
    tableProperties.put(TableProperties.FORMAT_VERSION, "2");

    return EncryptionUtil.createEncryptionManager(
        List.of(), tableProperties, EncryptionUtil.createKmsClient(catalogProperties));
  }
}
